[Phpmyadmin-git] [SCM] phpMyAdmin branch, master, updated. RELEASE_3_4_3_1-12970-gff074b1

Michal Čihař nijel at users.sourceforge.net
Thu Aug 4 15:21:35 CEST 2011


The branch, master has been updated
       via  ff074b1d2f984b0467e8424110caee9769ff4c89 (commit)
      from  a665c7d8a61ec56f76dd10c2815046113686e6f7 (commit)


- Log -----------------------------------------------------------------
commit ff074b1d2f984b0467e8424110caee9769ff4c89
Author: Michal Čihař <mcihar at suse.cz>
Date:   Thu Aug 4 15:21:06 2011 +0200

    Better parameter name

-----------------------------------------------------------------------

Summary of changes:
 libraries/core.lib.php |   12 ++++++------
 1 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/libraries/core.lib.php b/libraries/core.lib.php
index 7ba84d9..7befffb 100644
--- a/libraries/core.lib.php
+++ b/libraries/core.lib.php
@@ -562,15 +562,15 @@ function PMA_no_cache_header()
 /**
  * Sends header indicating file download.
  *
  * @param string $filename    Filename to include in headers.
  * @param string $mimetype    MIME type to include in headers.
  * @param int    $length      Length of content (optional)
  * @param bool   $avoid_cache Whether to include no-caching headers.
  *
  * @return nothing
  */
-function PMA_download_header($filename, $mimetype, $length = 0, $avoid_cache = true) {
-    if ($avoid_cache) {
+function PMA_download_header($filename, $mimetype, $length = 0, $no_cache = true) {
+    if ($no_cache) {
         PMA_no_cache_header();
     }
     header('Content-Description: File Transfer');
@@ -562,15 +562,15 @@ function PMA_no_cache_header()
  * Sends header indicating file download.
  *
- * @param string $filename    Filename to include in headers.
- * @param string $mimetype    MIME type to include in headers.
- * @param int    $length      Length of content (optional)
- * @param bool   $avoid_cache Whether to include no-caching headers.
+ * @param string $filename Filename to include in headers.
+ * @param string $mimetype MIME type to include in headers.
+ * @param int    $length   Length of content (optional)
+ * @param bool   $no_cache Whether to include no-caching headers.
  *
  * @return nothing


hooks/post-receive
-- 
phpMyAdmin




More information about the Git mailing list